==> nan_photo_selector-0.0.11.tar.gz: example/lib/main.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:nan_photo_selector/commonUploadImgWidget.dart';
import 'package:nan_photo_selector/nan_photo_selector.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  List<Widget> images = [];
  List<File> fileList =[];
  bool isUpload = false;

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    // We also handle the message potentially returning null.
    try {
      platformVersion =
          await NanPhotoSelector.platformVersion ?? 'Unknown platform version';
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: SingleChildScrollView(
          child: Column(
            children: [
              NanCommonUploadImgWidget(uploadTitle: "营业执照",images: images,onSelected: (List<File> fileListSel, List<Widget> imagesSel){
                    images.addAll(imagesSel);
                    fileList.addAll(fileListSel);
                    setState(() { });
                  },onDelete: (int index){
                    images.removeAt(index);
                    fileList.removeAt(index-1);
                    setState(() { });
                  },isFinish: isUpload,),
            ],
          ),
        ),
      ),
    );
  }
}

==> nan_photo_selector-0.0.16.tar.gz: example/lib/main.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:nan_photo_selector/commonUploadImgWidget.dart';
import 'package:nan_photo_selector/nan_photo_selector.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  List<Widget> images = [];
  List<File> fileList =[];
  bool isUpload = false;

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    // We also handle the message potentially returning null.
    try {
      platformVersion =
          await NanPhotoSelector.platformVersion ?? 'Unknown platform version';
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        backgroundColor: Color.fromRGBO(240, 242, 245, 1),
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: SingleChildScrollView(
          child: Column(
            children: [
              NanCommonUploadImgWidget(uploadTitle: "营业执照",imgMaxNum: null,images: images,onSelected: (List<File> fileListSel, List<Widget> imagesSel){
                    images.addAll(imagesSel);
                    fileList.addAll(fileListSel);
                    setState(() { });
                  },onDelete: (int index){
                    images.removeAt(index);
                    fileList.removeAt(index-1);
                    setState(() { });
                  },isFinish: isUpload,),
            ],
          ),
        ),
      ),
    );
  }
}
